<?php

namespace App\Http\Controllers\backend;

use App\Agency;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class AgencyController extends BackendController
{
    /***
     * @var Agency
     */
    private $_agencyModel;

    /***
     * Constructor
     *
     * @param $request
     * @param Agency $agencyModel
     */
    public function __construct(Request $request, Agency $agencyModel)
    {
        $this->_agencyModel = $agencyModel;
        parent::__construct(  );
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $data['agencies']=$this->_agencyModel->listAgencies($request);
        $data['breadcrumbs'] = [
            [
                'title' => 'Agencies',
                'url' => 'agencies',
            ]
        ];
        view()->share('page_title', 'All Agencies');
        return view('backend.agencies.index',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['breadcrumbs'] = [
            [
                'title' => 'Agencies',
                'url' => 'agencies',
            ]
        ];
        view()->share('page_title', 'Add New Agency');
        return view('backend.agencies.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'name' => 'required|max:30',
        ];
        $this->validate($request, $rules);
        $agency=$this->_agencyModel->InsertOrUpdateAgency($request);
        return redirect(url('agencies'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['agency'] = Agency::findOrFail($id);
        $data['breadcrumbs'] = [
            [
                'title' => 'Agencies',
                'url' => 'agencies',
            ]
        ];
        view()->share('page_title', 'Modify Agency');
        return view('backend.agencies.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'name' => 'required|max:30',
        ];
        $this->validate($request, $rules);
        $agency=$this->_agencyModel->InsertOrUpdateAgency($request,$id);
        return redirect(url('agencies'))->with('success', 'Your record has been update successfully.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $agency = Agency::findOrFail($id);
        $agency->delete();
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }
}
