<?php

namespace App\Http\Controllers\backend;

use App\Agency;
use App\Area;
use App\Shop;
use Auth;
use App\City;
use App\Country;
use App\Product;
use App\RevisitType;
use App\TargetGrade;
use App\User;
use App\UserArea;
use App\UserRole;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class AreaController extends BackendController
{
    /***
     * @var Area
     */
    private $_areaModel;

    /***
     * Constructor
     *
     * @param $request
     * @param Area $areaModel
     */
    public function __construct(Request $request, Area $areaModel)
    {
        parent::__construct(  );
        $this->_areaModel = $areaModel;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $data['sales_officers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
            $query->orwhere('name', '=', 'ase');
        })->get();
        $data['areas']=$this->_areaModel->listAreas($request);
        $data['breadcrumbs'] = [
            [
                'title' => 'Areas',
                'url' => 'areas',
            ]
        ];
        view()->share('page_title', 'All Areas');
        return view('backend.areas.index',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['sales_officers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
            $query->orwhere('name', '=', 'ase');
            $query->orwhere('name', '=', 'asm');
        })->get();
        $data['countries']=Country::all();
        $data['cities']=City::all();
        $data['distributors']=Shop::where('customer_type','Distributer')->get();
        $data['revisit_types']=RevisitType::all();
        $data['breadcrumbs'] = [
            [
                'title' => 'Areas',
                'url' => 'areas',
            ]
        ];
        view()->share('page_title', 'Add New Area');
        return view('backend.areas.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'name' => 'required|max:70',
            'city' => 'required',
            're_visit_type' => 'required',
        ];
        if($request->input('re_visit_type')!='' && $request->input('re_visit_type')==1){
            $rules['re_visit']=  'required';
        }elseif($request->input('re_visit_type')!='' && $request->input('re_visit_type')==2){
              $rules['week']=  'required|array|min:1';
        }elseif($request->input('re_visit_type')!='' && $request->input('re_visit_type')==3){
              $rules['month_days']=  'required';
          }

        $this->validate($request, $rules);
        $area=$this->_areaModel->InsertOrUpdateArea($request);
        return redirect(url('areas'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['sales_officers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
            $query->orwhere('name', '=', 'ase');
            $query->orwhere('name', '=', 'asm');
        })->get();
        $data['area'] = Area::findOrFail($id);
        $data['user_area'] = UserArea::where('area_id',$id)->get();
        $data['countries']=Country::all();
        $data['distributors']=Shop::where('customer_type','Distributer')->get();
        $data['cities']=City::all();
        $data['products']=Product::select(['id','name'])->get();
        $data['target_grades']=TargetGrade::select(['id','grade','value'])->get();
        $data['revisit_types']=RevisitType::all();
        $data['breadcrumbs'] = [
            [
                'title' => 'Areas',
                'url' => 'areas',
            ]
        ];
        view()->share('page_title', 'Modify Area');
        return view('backend.areas.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'name' => 'required|max:70',
            'city' => 'required',
            're_visit_type' => 'required',
        ];
        if($request->input('re_visit_type')!='' && $request->input('re_visit_type')==1){
            $rules['re_visit']=  'required';
        }elseif($request->input('re_visit_type')!='' && $request->input('re_visit_type')==2){
            $rules['week']=  'required|array|min:1';
        }elseif($request->input('re_visit_type')!='' && $request->input('re_visit_type')==3){
            $rules['month_days']=  'required';
        }
        $this->validate($request, $rules);
        $area=$this->_areaModel->InsertOrUpdateArea($request,$id);
        return redirect()->back()->with("success", "Your record has been update successfully.");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $area = Area::findOrFail($id);
        $area->delete();
        $user_area = UserArea::where('area_id',$id)->delete();
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }

}
