<?php

namespace App\Http\Controllers\backend;

use App\Bilti;
use App\Product;
use App\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Auth;
class BiltiController extends BackendController
{
    /***
     * @var Bilti
     */
    private $_bilti;

    /***
     * Constructor
     *
     * @param $request
     * @param  $biltiModel
     */
    public function __construct(Request $request, Bilti $biltiModel)
    {
        parent::__construct(  );
        $this->_bilti = $biltiModel;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $data['bilti']=$this->_bilti->listBilti($request);
        $data['breadcrumbs'] = [
            [
                'title' => 'Bilty',
                'url' => 'bilty',
            ]
        ];
        view()->share('page_title', 'All Bilty');
        return view('backend.bilti.index',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['sales_officers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'rsm');
        })->get();
        $data['suppliers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'main_su');
        })->get();
        $data['breadcrumbs'] = [
            [
                'title' => 'Bilty',
                'url' => 'bilty',
            ]
        ];
        view()->share('page_title', 'Add New Bilty');
        return view('backend.bilti.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'supplier' => 'required',
            'delivered_to' => 'required',
            'bilti_no' => 'required',
            'bilti_date' => 'required',
        ];
        $this->validate($request, $rules);
        $so=$this->_bilti->InsertOrUpdate($request);
        return redirect(url('bilty'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $data['bilty'] = Bilti::where('id',$id)->with(['products'])->first();
        $data['breadcrumbs'] = [
            [
                'title' => 'Bilty',
                'url' => 'bilty',
            ]
        ];
        view()->share('page_title', 'View Bilty Detail');
        return view('backend.bilti.show', $data);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['bilt'] = Bilti::findOrFail($id);
        $data['products']= Product::all();
        $data['sales_officers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'rsm');
        })->get();
        $data['suppliers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'main_su');
        })->get();
        $data['breadcrumbs'] = [
            [
                'title' => 'Bilty',
                'url' => 'bilty',
            ]
        ];
        view()->share('page_title', 'Modify Bilty');
        return view('backend.bilti.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'supplier' => 'required',
            'delivered_to' => 'required',
            'bilti_no' => 'required',
            'bilti_date' => 'required',
        ];
        $this->validate($request, $rules);
        $so=$this->_bilti->InsertOrUpdate($request,$id);
        return redirect()->back()->with("success", "Your record has been update successfully.");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $target = Bilti::findOrFail($id);
        $data=$this->_bilti->updateStock($target->id,$target->stock_booking_id);
        $target->delete();
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }
}
