<?php

namespace App\Http\Controllers\backend;

use App\Category;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class CategoryController extends BackendController
{
    /***
     * @var Category
     */
    private $_categoryModel;

    /***
     * Constructor
     *
     * @param $request
     * @param Category $categoryModel
     */
    public function __construct(Request $request, Category $categoryModel)
    {
        parent::__construct(  );
        $this->_categoryModel = $categoryModel;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $data['categories']=$this->_categoryModel->listCategories($request);
        $data['breadcrumbs'] = [
            [
                'title' => 'Categories',
                'url' => 'categories',
            ]
        ];
        view()->share('page_title', 'All Categories');
        return view('backend.categories.index',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['breadcrumbs'] = [
            [
                'title' => 'Categories',
                'url' => 'categories',
            ]
        ];
        view()->share('page_title', 'Add New Category');
        return view('backend.categories.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'name' => 'required|max:30',
        ];
        $this->validate($request, $rules);
        $category=$this->_categoryModel->InsertCategory($request);
        return redirect(url('cities'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['category'] = Category::findOrFail($id);
        $data['breadcrumbs'] = [
            [
                'title' => 'Categories',
                'url' => 'categories',
            ]
        ];
        view()->share('page_title', 'Modify category');
        return view('backend.categories.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'name' => 'required|max:30',
        ];
        $this->validate($request, $rules);
        $category=$this->_categoryModel->UpdateCategory($request,$id);
        return redirect(url('categories'))->with('success', 'Your record has been update successfully.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $category = Category::findOrFail($id);
        $category->delete();
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }
}
