<?php

namespace App\Http\Controllers\backend;
use Mail;
use App\City;
use App\Region;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class CityController extends BackendController
{
    /***
     * @var City
     */
    private $_cityModel;

    /***
     * Constructor
     *
     * @param $request
     * @param City $cityModel
     */
    public function __construct(Request $request, City $cityModel)
    {
        parent::__construct(  );
        $this->_cityModel = $cityModel;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $data['cities']=$this->_cityModel->listCities($request);
        $data['breadcrumbs'] = [
            [
                'title' => 'Cities',
                'url' => 'cities',
            ]
        ];
        view()->share('page_title', 'All Cities');
        return view('backend.cities.index',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['regions']=Region::all();
        $data['breadcrumbs'] = [
            [
                'title' => 'Cities',
                'url' => 'cities',
            ]
        ];
        view()->share('page_title', 'Add New City');
        return view('backend.cities.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'name' => 'required|max:30',
            'region' => 'required',
        ];
        $this->validate($request, $rules);
        $city=$this->_cityModel->InsertOrUpdateCity($request);
        return redirect(url('cities'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['city'] = City::findOrFail($id);
        $data['regions']=Region::all();
        $data['breadcrumbs'] = [
            [
                'title' => 'Cities',
                'url' => 'cities',
            ]
        ];
        view()->share('page_title', 'Modify City');
        return view('backend.cities.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'name' => 'required|max:30',
            'region' => 'required',
        ];
        $this->validate($request, $rules);
        $city=$this->_cityModel->InsertOrUpdateCity($request,$id);
        return redirect(url('cities'))->with('success', 'Your record has been update successfully.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $city = City::findOrFail($id);
        $city->delete();
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }
}
