<?php

namespace App\Http\Controllers\backend;

use App\City;
use App\Country;
use App\Currency;
use App\Order;
use App\Product;
use App\Region;
use App\SoPoint;
use App\User;
use Carbon\Carbon;
use Edujugon\PushNotification\PushNotification;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use DB;
class CountryController extends BackendController
{
    /***
     * @var Country
     */
    private $_countryModel;

    /***
     * Constructor
     *
     * @param $request
     * @param Country $countryModel
     */
    public function __construct(Request $request, Country $countryModel)
    {
        parent::__construct(  );
        $this->_countryModel = $countryModel;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $data['countries']=$this->_countryModel->listCountries($request);
        $data['breadcrumbs'] = [
            [
                'title' => 'Countries',
                'url' => 'countries',
            ]
        ];
        view()->share('page_title', 'All Countries');
        return view('backend.countries.index',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['breadcrumbs'] = [
            [
                'title' => 'Countries',
                'url' => 'countries',
            ]
        ];
        view()->share('page_title', 'Add New country');
        return view('backend.countries.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'name' => 'required|max:30',
        ];
        $this->validate($request, $rules);
        $country=$this->_countryModel->InsertCountry($request);
        return redirect(url('countries'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['country'] = Country::findOrFail($id);
        $data['breadcrumbs'] = [
            [
                'title' => 'Countries',
                'url' => 'countries',
            ]
        ];
        view()->share('page_title', 'Modify Country');
        return view('backend.countries.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'name' => 'required|max:30',
        ];
        $this->validate($request, $rules);
        $country=$this->_countryModel->UpdateCountry($request,$id);
        return redirect(url('countries'))->with('success', 'Your record has been update successfully.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $country = Country::findOrFail($id);
        $country->delete();
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }
    public function countryCurrencies($id)
    {
       $data=Currency::select('id','name')->where('country_id',$id)->get();
       return $data;
    }
    public function countryRegions($id)
    {
       $data=Region::select('id','name')->where('country_id',$id)->get();
       return $data;
    }
    public function regionCities($id)
    {
       $data=City::select('id','name')->where('region_id',$id)->get();
       return $data;
    }
}
