<?php

namespace App\Http\Controllers\backend;

use App\Country;
use App\Currency;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class CurrencyController extends BackendController
{
    /***
     * @var Currency
     */
    private $_Model;

    /***
     * Constructor
     *
     * @param $request
     * @param Currency $Model
     */
    public function __construct(Request $request, Currency $Model)
    {
        parent::__construct(  );
        $this->_Model = $Model;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $data['currencies']=$this->_Model->listCurrency();
        $data['breadcrumbs'] = [
            [
                'title' => 'Currencies',
                'url' => 'currencies',
            ]
        ];
        view()->share('page_title', 'All Currencies');
        return view('backend.currency.index',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['countries'] = Country::all();
        $data['breadcrumbs'] = [
            [
                'title' => 'Currencies',
                'url' => 'currencies',
            ]
        ];
        view()->share('page_title', 'Add New Currency');
        return view('backend.currency.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'name' => 'required|max:30',
        ];
        $this->validate($request, $rules);
        $result=$this->_Model->InsertOrUpdateCurrency($request);
        return redirect(url('currencies'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {

    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['countries'] = Country::all();
        $data['currency'] = Currency::findOrFail($id);
        $data['breadcrumbs'] = [
            [
                'title' => 'Currencies',
                'url' => 'currencies',
            ]
        ];
        view()->share('page_title', 'Modify Currency');
        return view('backend.currency.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'name' => 'required|max:30',
        ];
        $this->validate($request, $rules);
        $result=$this->_Model->InsertOrUpdateCurrency($request,$id);
        return redirect()->back()->with("success", "Your record has been update successfully.");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $result = Currency::findOrFail($id);
        $result->delete();
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }
}
