<?php

namespace App\Http\Controllers\backend;

use App\Expense;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class ExpenseController extends BackendController
{
    /***
     * @var Expense
     */
    private $_Model;

    /***
     * Constructor
     *
     * @param $request
     * @param Expense $areaModel
     */
    public function __construct(Request $request, Expense $Model)
    {
        parent::__construct(  );
        $this->_Model = $Model;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $data['expenses']=$this->_Model->listExpense($request);
        $data['breadcrumbs'] = [
            [
                'title' => 'Expense',
                'url' => 'expense',
            ]
        ];
        view()->share('page_title', 'All Expense');
        return view('backend.expense.index',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['breadcrumbs'] = [
            [
                'title' => 'Expense',
                'url' => 'expense',
            ]
        ];
        view()->share('page_title', 'Add New Expense');
        return view('backend.expense.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'name' => 'required|max:70',
        ];
        $this->validate($request, $rules);
        $expense=$this->_Model->InsertOrUpdate($request);
        return redirect(url('expense'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['expense'] = Expense::findOrFail($id);
        $data['breadcrumbs'] = [
            [
                'title' => 'Expense',
                'url' => 'expense',
            ]
        ];
        view()->share('page_title', 'Modify Area');
        return view('backend.expense.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'name' => 'required|max:70',
        ];
        $this->validate($request, $rules);
        $expense=$this->_Model->InsertOrUpdate($request,$id);
        return redirect()->back()->with("success", "Your record has been update successfully.");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $expense = Expense::findOrFail($id);
        $expense->delete();
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }
}
