<?php

namespace App\Http\Controllers\backend;

use App\Area;
use App\Job;
use App\JobDetail;
use App\User;
use App\UserArea;
use App\UserRole;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Auth;

class JobController extends BackendController
{
    /***
     * @var Job
     */
    private $_jobModel;

    /***
     * Constructor
     *
     * @param $request
     * @param Job $jobModel
     */
    public function __construct(Request $request, Job $jobModel)
    {
        parent::__construct(  );
        $this->_jobModel = $jobModel;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $data['jobs']=$this->_jobModel->listJobs($request);
        $data['sales_officers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
        })->get();
        $data['breadcrumbs'] = [
            [
                'title' => 'Jobs',
                'url' => 'jobs',
            ]
        ];
        view()->share('page_title', 'All Jobs');
        return view('backend.jobs.index',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['sales_officers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
        })->get();
        $data['areas']=[];
        $data['breadcrumbs'] = [
            [
                'title' => 'Jobs',
                'url' => 'jobs',
            ]
        ];
        view()->share('page_title', 'Add New Job');
        return view('backend.jobs.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'sale_officer' => 'required',
            'area' => 'required',
            'start_date' => 'required',
            'end_date' => 'required',
        ];
        $this->validate($request, $rules);
        $job=$this->_jobModel->InsertOrUpdateJob($request);
        return redirect(url('jobs'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
       $data['job']= Job::findOrFail($id);
        $data['breadcrumbs'] = [
            [
                'title' => 'Jobs',
                'url' => 'jobs',
            ]
        ];
        view()->share('page_title', 'View Job Detail');
        return view('backend.jobs.show', $data);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['job'] = Job::findOrFail($id);
        $role=UserRole::select(['user_id'])->where('role_id',4)->get();
        $data['sales_officers']=User::where('agency_id',Auth::user()->agency_id)->whereIn('id', $role)->get();
        $users=UserArea::select(['area_id'])->where('user_id',$data['job']['user_id'])->get();
        $user_area=[];
        foreach ($users as $user){
            if(isset($user['area_id']) && !empty($user['area_id'])){
                $user_area[]=$user['area_id'];
            }
        }
        $data['areas']=Area::select(['id','name'])->whereIn('id', $user_area)->get();
        $data['breadcrumbs'] = [
            [
                'title' => 'Jobs',
                'url' => 'jobs',
            ]
        ];
        view()->share('page_title', 'Modify Job');
        return view('backend.jobs.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'sale_officer' => 'required',
            'area' => 'required',
            'start_date' => 'required',
        ];
        $this->validate($request, $rules);
        $job=$this->_jobModel->InsertOrUpdateJob($request,$id);
        return redirect()->back()->with("success", "Your record has been update successfully.");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $job = Job::findOrFail($id);
        $job->delete();
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }
}
