<?php

namespace App\Http\Controllers\backend;

use App\Agency;
use App\Bilti;
use App\BiltiDetail;
use App\BiltiDetialType;
use App\BiltyImage;
use App\Country;
use App\Order;
use App\OrderImages;
use App\OrderProduct;
use App\Payment;
use App\Product;
use App\PushNotificationToken;
use App\Role;
use App\Shop;
use App\StockBooking;
use App\StockBookingDetail;
use App\StockBookingDetailCategory;
use App\SupplierSo;
use App\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Auth;
use Edujugon\PushNotification\PushNotification;
class OrderController extends BackendController
{
    /***
     * @var Order
     */
    private $_orderModel;

    /***
     * Constructor
     *
     * @param $request
     * @param Order $orderModel
     */
    public function __construct(Request $request, Order $orderModel)
    {
        parent::__construct(  );
        $this->_orderModel = $orderModel;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $type=$request->input('type');
        if($type==null){
            if($request->session()->has('tab_active'))
            {
                $type= session('tab_active');
            }
        }

        $data['orders']=$this->_orderModel->listOrders($request,$type);
        $data['total_processed_order']=Order::where('status','Processed')->count();
        $data['total_delivered_order']=Order::where('status','Delivered')->whereNotIn('type', ['Sample'])->count();
        $data['total_cancelled_order']=Order::where('status','Cancelled')->count();
        $data['total_rejected_order']=Order::where('status','Rejected')->count();
        $data['total_returned_order']=Order::where('status','Returned')->count();
        $data['countries']=Country::all();
        if($type=='Delivered'){
            $data['active_order']='Delivered';
            session(['tab_active' => 'Delivered']);
        }elseif($type=='Cancelled'){
            $data['active_order']='Cancelled';
            session(['tab_active' => 'Cancelled']);
        }elseif($type=='Rejected'){
            $data['active_order']='Rejected';
            session(['tab_active' => 'Rejected']);
        }elseif($type=='Returned'){
            $data['active_order']='Returned';
            session(['tab_active' => 'Returned']);
        }else{
            if($type=='Processed'){
                $data['active_order']='Processed';
                session(['tab_active' => 'Processed']);
            }else if($request->session()->has('tab_active'))
            {
                $data['active_order']= session('tab_active');
            }else{
                $data['active_order']='Processed';
                session(['tab_active' => 'Processed']);
            }
        }
        $data['sales_officers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
        })->get();
        $data['breadcrumbs'] = [
            [
                'title' => 'Orders',
                'url' => 'orders',
            ]
        ];
        view()->share('page_title', 'All Orders');
        return view('backend.orders.index2',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {

        $data['users'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
                $query->where('name', '=', 'so');
                $query->orwhere('name', '=', 'ase');
        })->get();
        $data['breadcrumbs'] = [
            [
                'title' => 'Orders',
                'url' => 'orders',
            ]
        ];
        view()->share('page_title', 'Add New Order');
        return view('backend.orders.modify',$data);
    }
    public function scopeIsRole($query, $role) {
        return $query->whereHas(
            'roles', function($query) use ($role){
            $query->where('name', $role);
        }
        );
    }
    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'shop' => 'required',
            'price' => 'required',
            'payment' => 'required',
            'booked_by' => 'required',
            'date_to_deliver' => 'required',
            'status' => 'required',
        ];
        $this->validate($request, $rules);
        $order=$this->_orderModel->InsertOrUpdateOrder($request);
        if($request->input('type')=="Sample"){
            return redirect(url('orders/sample'))->with('success', 'Your record has been added successfully.');
        }
        if($request->input('status')=="Returned"){
            return redirect(url('orders'))->with('success', 'Your record has been added successfully.');
        }
        return redirect(url('booked-orders'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $data['order'] = Order::findOrFail($id);
        $data['breadcrumbs'] = [
            [
                'title' => 'Orders',
                'url' => 'orders',
            ]
        ];
        view()->share('page_title', 'View Order Detail');
        return view('backend.orders.show', $data);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['order'] = Order::findOrFail($id);
        $data['users'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
            $query->orwhere('name', '=', 'ase');
        })->get();
        $data['products']=Product::select(['id','name'])->get();
        $data['breadcrumbs'] = [
            [
                'title' => 'Orders',
                'url' => 'orders',
            ]
        ];
        view()->share('page_title', 'Modify Order');
        return view('backend.orders.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'shop' => 'required',
            'price' => 'required',
            'payment' => 'required',
            'booked_by' => 'required',
            'date_to_deliver' => 'required',
            'status' => 'required',
        ];
        $this->validate($request, $rules);
        $order=$this->_orderModel->InsertOrUpdateOrder($request,$id);
        return redirect()->back()->with("success", "Your record has been Updated successfully.");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $order = Order::findOrFail($id);
        $order->delete();

        // Remove all Order Product
        OrderProduct::where('order_id',$id)->delete();

        // Remove all Order Images
        $img=OrderImages::where('order_id',$id)->select(['image'])->get();
        OrderImages::where('order_id',$id)->delete();
        if(count($img)>0){
            foreach ($img as $val){
                $file =public_path() .str_replace(url(''),"",$val['image']);
                if (file_exists($file)) {
                    @unlink($file);
                }
            }
        }
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }

    // Sales
    public function Sales(Request $request){
        $data['sales_officers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
        })->get();
        $products=[];
        $tenure=[];
        $price=0;
        $payment=0;
        $discount=0;
        $orders=null;
        if ($request->sale_officer != '') {
            if($request->input('tenure')=="last_week"){
                $orders=Order::where('booked_by',$request->sale_officer)
                    ->where('status','Delivered')
                    ->where('type', '!=', 'Sample')
                    ->whereBetween('date_to_deliver',[date('Y-m-d', strtotime('-7 days')),date("Y-m-d")])
                    ->get();
            }elseif ($request->input('tenure')=="last_month"){
                $orders=Order::where('booked_by',$request->sale_officer)
                    ->where('status','Delivered')
                    ->where('type', '!=', 'Sample')
                    ->whereBetween('date_to_deliver', [date('Y-m-d', strtotime('-30 days')),date("Y-m-d")])
                    ->get();
            }elseif ($request->input('tenure')=="specific_date"){
                $orders=Order::where('booked_by',$request->sale_officer)
                    ->where('status','Delivered')
                    ->where('type', '!=', 'Sample')
                    ->where('date_to_deliver',$request->specific_date )
                    ->get();
            }elseif ($request->input('tenure')=="date_range"){
                $orders=Order::where('booked_by',$request->sale_officer)
                    ->where('status','Delivered')
                    ->where('type', '!=', 'Sample')
                    ->whereBetween('date_to_deliver',[$request->start_date,$request->end_date])
                    ->get();
            }
            if(count($orders)>0){
                foreach ($orders as $key=>$order){
                    $price=$price+$order->payment;
                    $payment=$payment+$order->payment;
                    if(count($order->products)>0){
                        foreach ($order->products as $key2=>$order_product){
                            if (array_key_exists($order_product->product_id,$products)){
                                $products[$order_product->product_id]=(int)$products[$order_product->product_id]+ (int)$order_product->quantity;
                            }else{
                                $products[$order_product->product_id]=(int) $order_product->quantity;
                            }
                        }
                    }
                }
            }
        }
        if(count($products)>0){
            foreach ($products as $key3=>$product){
                $value=Product::select(['id','name','product_code'])->where('id',$key3)->first();
                $obj = new \stdClass;
                $obj->product=$value->name.' ('.$value->product_code.' )';
                $obj->quantity=$product;
                $tenure[]=$obj;
            }
        }
        $data['tenures']=$tenure;
        $data['price']=$price;
        $data['discount']=$price-$payment;
        $data['payment']=$payment;
        $data['breadcrumbs'] = [
            [
                'title' => 'Sales Summary',
                'url' => 'reports/sales',
            ]
        ];
        view()->share('page_title', 'Sales Summary');
        return view('backend.orders.summary',$data);
    }

     // salesRecovery
    public function salesRecovery(Request $request){
        $data['sales_officers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
        })->get();
        $tenures=[];
        $size=0;
        $sales=0;
        $recovery=0;
        if ($request->sale_officer != '') {
            switch ($request->input('tenure')){
                case 'last_week':
                    $payments=Payment::where('user_id',$request->sale_officer)
                        ->where('payment_type','Cash')
                        ->whereBetween('promise_cheque_date',[date('Y-m-d', strtotime('-7 days')),date("Y-m-d")])
                        ->get();
                    $recovery=Payment::where('user_id',$request->sale_officer)
                        ->where('payment_type','Cash')
                        ->whereBetween('promise_cheque_date',[date('Y-m-d', strtotime('-7 days')),date("Y-m-d")])
                        ->sum('amount');
                    $orders=Order::where('booked_by',$request->sale_officer)
                        ->where('status','Delivered')
                        ->where('type', '!=', 'Sample')
                        ->whereBetween('date_to_deliver',[date('Y-m-d', strtotime('-7 days')),date("Y-m-d")])
                        ->get();
                    $sales=Order::where('booked_by',$request->sale_officer)
                        ->where('status','Delivered')
                        ->where('type', '!=', 'Sample')
                        ->whereBetween('date_to_deliver',[date('Y-m-d', strtotime('-7 days')),date("Y-m-d")])
                        ->sum('payment');
                    break;
                case 'last_month':
                    $payments =Payment::where('user_id',$request->sale_officer)
                        ->where('payment_type','Cash')
                        ->whereBetween('promise_cheque_date',[date('Y-m-d', strtotime('-30 days')),date("Y-m-d")])
                        ->get();
                    $recovery =Payment::where('user_id',$request->sale_officer)
                        ->where('payment_type','Cash')
                        ->whereBetween('promise_cheque_date',[date('Y-m-d', strtotime('-30 days')),date("Y-m-d")])
                        ->sum('amount');
                    $orders=Order::where('booked_by',$request->sale_officer)
                        ->where('status','Delivered')
                        ->where('type', '!=', 'Sample')
                        ->whereBetween('date_to_deliver',[date('Y-m-d', strtotime('-30 days')),date("Y-m-d")])
                        ->get();
                    $sales=Order::where('booked_by',$request->sale_officer)
                        ->where('status','Delivered')
                        ->where('type', '!=', 'Sample')
                        ->whereBetween('date_to_deliver',[date('Y-m-d', strtotime('-30 days')),date("Y-m-d")])
                        ->sum('payment');
                    break;
                case 'specific_date':
                    $payments=Payment::where('user_id',$request->sale_officer)
                        ->where('payment_type','Cash')
                        ->where('promise_cheque_date',$request->specific_date)
                        ->get();
                    $recovery=Payment::where('user_id',$request->sale_officer)
                        ->where('payment_type','Cash')
                        ->where('promise_cheque_date',$request->specific_date)
                        ->sum('amount');
                    $orders=Order::where('booked_by',$request->sale_officer)
                        ->where('status','Delivered')
                        ->where('type', '!=', 'Sample')
                        ->where('date_to_deliver',$request->specific_date)
                        ->get();
                    $sales=Order::where('booked_by',$request->sale_officer)
                        ->where('status','Delivered')
                        ->where('type', '!=', 'Sample')
                        ->where('date_to_deliver',$request->specific_date)
                        ->sum('payment');
                    break;
                case 'date_range':
                    $payments=Payment::where('user_id',$request->sale_officer)
                        ->where('payment_type','Cash')
                        ->whereBetween('promise_cheque_date',[$request->start_date,$request->end_date])
                        ->get();
                    $recovery=Payment::where('user_id',$request->sale_officer)
                        ->where('payment_type','Cash')
                        ->whereBetween('promise_cheque_date',[$request->start_date,$request->end_date])
                        ->sum('amount');
                    $orders=Order::where('booked_by',$request->sale_officer)
                        ->where('status','Delivered')
                        ->where('type', '!=', 'Sample')
                        ->whereBetween('date_to_deliver',[$request->start_date,$request->end_date])
                        ->get();
                    $sales=Order::where('booked_by',$request->sale_officer)
                        ->where('status','Delivered')
                        ->where('type', '!=', 'Sample')
                        ->whereBetween('date_to_deliver',[$request->start_date,$request->end_date])
                        ->sum('payment');
                    break;
                default:
                    break;
            }
        }
        if(isset($orders) && count($orders)>0){
            foreach ($orders as $key=>$order){
                $tenures[$key]=$order;
                $tenures[$key]['date']=$order['date_to_deliver'];
                $tenures[$key]['ledger_type']='order';

            }
            $size=count($orders);
        }
        if(isset($payments) && count($payments)>0){
            foreach ($payments as $index=>$payment){
                $tenures[$size]=$payment;
                $tenures[$size]['date']=$payment['promise_cheque_date'];
                $tenures[$size]['ledger_type']='payment';
                $size++;
            }
        }
        usort($tenures, function($a, $b) {
            return strtotime($a['date']) - strtotime($b['date']);
        });
        $data['sale']=$sales;
        $data['recovery']=$recovery;
        $data['tenures']=$tenures;
        $data['breadcrumbs'] = [
            [
                'title' => 'Sales & Recovery',
                'url' => 'reports/sales&recovery',
            ]
        ];
        view()->share('page_title', 'Sales & Recovery');
        return view('backend.orders.payment_summary',$data);
    }
    public function dubaisalesRecovery(Request $request){
        $so_Id = 13;
        $start_date = $request->get('start_date');
        $end_date = $request->get('end_date');
        $start_date = date_create($start_date);
        $end_date = date_create($end_date);
        $difference = date_diff($start_date,$end_date);
        $days = $difference->format('%a');
        $sale_officers_data = array();
        for ($x=0;$x<=$days;$x++){
            $sale = 0;
            $recovery = 0;
            $orders = Order::where('booked_by',$so_Id)
                ->whereDate('date_to_deliver','=',$start_date)
                ->where('status','=','Delivered')->where('type','!=','Sample')
                ->get();
            $supplier=SupplierSo::select('supplier_id')->where('so_id',$so_Id)->get();
            $user_ids=[];
            $user_ids[]=$so_Id;
            foreach ($supplier as $su){
                $user_ids[]=$su['supplier_id'];
            }
            $payments =Payment:: wherein('user_id', $user_ids)
                ->whereDate('promise_cheque_date','=',$start_date)
                ->where('payment_type','=','Cash')
                ->where('shop_id','!=',0)
                ->get();
            $sale_officers_data[$x]['date'] = $start_date->format('Y-m-d');
            if(count($orders)>0){
                foreach ($orders as $order){
                    $sale +=  $order['payment'];
                }
            }
            if(count($payments)>0){
                foreach ($payments as $payment){
                    $recovery +=  $payment['amount'];
                }
            }

            $sale_officers_data[$x]['sale'] = $sale;
            $sale_officers_data[$x]['recovery'] = $recovery;
            $start_date = $start_date->modify('+1 day');
        }
//dd($sale_officers_data);
        view()->share('page_title', 'Sales & Recovery');
        $data['sale_officers_data']=$sale_officers_data;
//        dd($data);
        return view('backend.orders.dubai_salesrecovery_summary',$data);
    }
//Sample
    public function Sample(Request $request){
        $data['sales_officers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
        })->get();
        if(isset($request->sale_officer)){
            $data['samples']=Order::where('booked_by',$request->sale_officer)->where('type','Sample')->paginate(session()->get('site_settings')['results_per_page']);
        }else{
            $data['samples']=Order::where('type','Sample')->paginate(session()->get('site_settings')['results_per_page']);
        }
        $data['breadcrumbs'] = [
            [
                'title' => 'Orders Sample',
                'url' => 'orders/sample',
            ]
        ];
        view()->share('page_title', 'Orders Sample');
        return view('backend.orders.sample',$data);
    }
    // Stock order
    public function StockOrder(Request $request)
    {

        $data['sales_officers'] = User::where('id','!=',46)->where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'rsm');
        })->orwhere('id',13)
            ->get();
        $type=$request->input('type');
        if($type==null){
            if($request->session()->has('tab_active'))
            {
                $type= session('tab_active');
            }
        }
        if($type=='All'){
            $data['active_order']='All';
            session(['tab_active' => 'All']);
        }elseif($type=='Cancelled'){
            $data['active_order']='Cancelled';
            session(['tab_active' => 'Cancelled']);
        }elseif($type=='Booked'){
            $data['active_order']='Booked';
            session(['tab_active' => 'Booked']);
        }elseif($type=='Completed'){
            $data['active_order']='Completed';
            session(['tab_active' => 'Completed']);
        }else{
            if($request->session()->has('tab_active'))
            {
                $data['active_order']= session('tab_active');
            }else{
                $data['active_order']='All';
                session(['tab_active' => 'All']);
            }
        }
        $data['total_order']=StockBooking::count();
        $data['total_booked_order']=StockBooking::wherein('status',['Delivered','Booked'])->count();
        $data['total_cancelled_order']=StockBooking::where('status','Cancelled')->count();
        $data['total_completed_order']=StockBooking::where('status','Completed')->count();
        switch ($type){
            case "Cancelled":
                $data['stocks'] = StockBooking::where('status','Cancelled')->OrderBy('date','Desc');
                break;
            case "Booked":
                $data['stocks'] = StockBooking::wherein('status',['Delivered','Booked'])->OrderBy('date','Desc');
                break;
            case "Completed":
                $data['stocks'] = StockBooking::where('status','Completed')->OrderBy('date','Desc');
                break;
            default:
                $data['stocks'] = StockBooking::OrderBy('date','Desc');
        }


        if ($request->sale_officer != '') {
            $data['stocks']=$data['stocks']->where('booked_by', '=', $request->sale_officer);
        }
        $data['stocks']=$data['stocks']->with('BookedBy')->paginate(session()->get('site_settings')['results_per_page']);
        $data['breadcrumbs'] = [
            [
                'title' => 'RSM Orders',
                'url' => 'orders/stock',
            ]
        ];
        view()->share('page_title', 'All RSM Orders');
        return view('backend.orders.stock_orders',$data);
    }
    // Stock Order Detail
    public function StockOrderDetail($id)
    {
        $data['stock'] = StockBooking::where('id',$id)->first();
        $data['suppliers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'main_su');
        })->get();
        $data['breadcrumbs'] = [
            [
                'title' => 'Stock Orders',
                'url' => 'orders/stock',
            ]
        ];
        view()->share('page_title', 'All Stock Order Detail');
        return view('backend.orders.stock_orders_detail',$data);
    }
    // Stock Order Detail
    public function MarkOrder($id)
    {
        $data = StockBooking::where('id',$id)->first();
        $data->status="Completed";
        $data->save();
        return redirect()->back()->with("success", "Your record has been Added successfully.");
    }
    // Stock Bilty
    public function StockBilty($id,Request $request)
    {
        $rules = [
            'bilti_no' => 'required',
            'po_no' => 'required',
        ];
        $this->validate($request, $rules);
        $bilty = new Bilti();
        $bilty->stock_booking_id=$id;
        $bilty->agency_id=1;
        $bilty->supplier_id=$request->get('supplier');
        $bilty->delivered_to_id=$request->get('booked_by');
        $bilty->bilti_no=$request->get('bilti_no');
        $bilty->po_no=$request->get('po_no');
        if(!empty($request->get('bilti_date'))){
            $bilty->bilti_date=$request->get('bilti_date');
        }else{
            $bilty->bilti_date=date('Y-m-d');
        }
        $bilty->remarks=$request->get('remarks');
        $bilty->status='On The Way';
        $bilty->save();
        if(count($request->get('product'))>0){
            foreach ($request->get('product') as $value){
                // update stock booking product delivered
                $stock=StockBookingDetail::where('stock_booking_id',$id)->where('product_id',$value['id'])->first();
                if(!empty($value['quantity']) || $value['id']==12){
                // add bilty product
                    $detail=new BiltiDetail();
                    $detail->bilti_id=$bilty->id;
                    $detail->product_id=$value['id'];
                    $cot=Product::where('id',$value['id'])->first();
                    if($value['id']!=12){
                        if(!empty($cot)){
                            $detail->quantity=$value['quantity']*$cot->cotton;
                        }
                    }
                    $detail->save();
                    $facial=0;
                    if($value['id']==12){

                        if(count($request->get('product_category'))>0){
                            foreach ($request->get('product_category') as $category){
                                if(!empty($category['quantity'])){
                                    $type= new BiltiDetialType();
                                    $type->bilti_detial_id=$detail->id;
                                    $type->product_category_id=$category['id'];
                                    if(!empty($cot)){
                                        $type->quantity=$category['quantity']*$cot->cotton;
                                        $facial=$facial+($category['quantity']*$cot->cotton);
                                    }
                                    $type->save();
                                    if(!empty($stock)){
                                        $dc= StockBookingDetailCategory::where('stock_booking_detail_id',$stock->id)->where('product_category_id',$category['id'])->first();
                                        if(!empty($dc) && !empty($cot)){
                                            $dc->delivered=$dc->delivered+($category['quantity']*$cot->cotton);
                                            $dc->save();
                                        }
                                    }
                                }
                            }
                        }

                    }
                    if(!empty($stock)){
                        if($value['id']==12){
                            $stock->delivered=$stock->delivered+$facial;

                        }else{
                            if(!empty($cot)){
                                $stock->delivered=$stock->delivered+($value['quantity']*$cot->cotton);
                            }
                        }
                            StockBooking::where('id', $stock->stock_booking_id)
                                ->update(array('status' => 'Delivered'));
                        $stock->save();
                    }
                    if($value['id']==12)
                        $detail->quantity=$facial;
                    $detail->save();
                }
            }
        }
        for($i=-1,$j=0;$i<6;$i++,$j++){
            if ($request->hasFile('image'.$j)) {
                $filename = 'image-' . time() . rand(99, 199) . '.' . $request->file('image'.$j)->getClientOriginalExtension();
                $request->file('image'.$j)->move(config('constants.UPLOAD_PATH') . 'bilty/', $filename);
                if (isset($filename)){
                    $pro_image=new BiltyImage();
                    $pro_image->image = url('/uploads/bilty/'.$filename);
                    $pro_image->bilty_id = $bilty->id;
                    $pro_image->save();
                }
            }
        }
        // push notification recipients fetch
        $recipients = User::select('id')->whereHas('roles', function ($query) {
            $query->wherein('name', ['admin','super_admin']);
        })->get()->toarray();
        if(count($recipients)>0){
        // push notification device token fetch
            $fetch=[];
            $fetch=fetch_column_from_array($recipients,'id');
            $fetch[]=$bilty->delivered_to_id;
            $device_token=PushNotificationToken::select('id','token')->wherein('user_id',$fetch)->get();
       if(count($device_token)>0){
           // push notification send
           push_notification_send($bilty->id,'Bilty Dispatch',$bilty->remarks,fetch_column_from_array($device_token,'token'),'bilty');
       }
            return redirect()->back()->with("success", "Your record has been Added successfully.");
        }
    }
}
