<?php

namespace App\Http\Controllers\backend;

use App\PartyName;
use App\Region;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class PartyNameController extends BackendController
{
    /***
     * @var Party
     */
    private $_Model;

    /***
     * Constructor
     *
     * @param $request
     * @param City $Model
     */
    public function __construct(Request $request, PartyName $Model)
    {
        parent::__construct(  );
        $this->_Model = $Model;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $data['partynames']=$this->_Model->listAll($request);
        $data['breadcrumbs'] = [
            [
                'title' => 'Party Name',
                'url' => 'partynames',
            ]
        ];
        view()->share('page_title', 'All Party Name');
        return view('backend.partyname.index',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['regions']=Region::all();
        $data['breadcrumbs'] = [
            [
                'title' => 'Party Name',
                'url' => 'partynames',
            ]
        ];
        view()->share('page_title', 'Add New Party Name');
        return view('backend.partyname.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'name' => 'required',
            'region' => 'required',
        ];
        $this->validate($request, $rules);
        $city=$this->_Model->InsertOrUpdate($request);
        return redirect(url('partyname'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['partyname'] = PartyName::findOrFail($id);
        $data['regions']=Region::all();
        $data['breadcrumbs'] = [
            [
                'title' => 'Party Name',
                'url' => 'partynames',
            ]
        ];
        view()->share('page_title', 'Modify City');
        return view('backend.partyname.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'name' => 'required',
            'region' => 'required',
        ];
        $this->validate($request, $rules);
        $city=$this->_Model->InsertOrUpdate($request,$id);
        return redirect(url('partyname'))->with('success', 'Your record has been update successfully.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $city = PartyName::findOrFail($id);
        $city->delete();
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }
    public function Refresh($id)
    {
        $city=$this->_Model->refreshLedger($id);
        return redirect()->back()->with("success", "Your record has been Updated successfully.");

    }
}
