<?php

namespace App\Http\Controllers\backend;

use App\Bank;
use App\Payment;
use App\PaymentImage;
use App\Shop;
use App\User;

use Edujugon\PushNotification\PushNotification;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Auth;
class PaymentController extends BackendController
{
    /***
     * @var Payment
     */
    private $_paymentModel;

    /***
     * Constructor
     *
     * @param $request
     * @param Payment $paymentModel
     */
    public function __construct(Request $request, Payment $paymentModel)
    {
        parent::__construct(  );
        $this->_paymentModel = $paymentModel;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $data['payments']=$this->_paymentModel->listPayments($request);
        $data['sales_officers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
        })->get();

        $data['breadcrumbs'] = [
            [
                'title' => 'Payments',
                'url' => 'payments',
            ]
        ];
        view()->share('page_title', 'All Payments');
        return view('backend.payments.index',$data);
    }
    // pending Payment
    public function pendingPayment(Request $request)
    {
        $data['payments']=$this->_paymentModel->pendingPayments($request);
        $data['sales_officers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
        })->get();
        $data['breadcrumbs'] = [
            [
                'title' => 'Pending Cheque',
                'url' => 'payments/pending',
            ]
        ];
        view()->share('page_title', 'All Pending Cheque');
        return view('backend.payments.pending',$data);
    }
    // confirmPayment
    public function confirmPayment($id)
    {
        $payments=Payment::findorfail($id);
        $payments->payment_type='Cash';
        $shop=Shop::where('id',$payments->shop_id)->first();
        $shop->balance=($shop->balance)+($payments->amount);
        $shop->save();
        $payments->balance= $shop->balance;
        $payments->	promise_cheque_date= date('Y-m-d ');;
        $payments->save();
        return redirect()->back()->with("success", "Your record has been update successfully.");
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['users'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
        })->get();
        $data['shops']=Shop::where('agency_id',Auth::user()->agency_id)->get();
        $data['banks']=Bank::all();
        $data['breadcrumbs'] = [
            [
                'title' => 'Payments',
                'url' => 'payments',
            ]
        ];
        view()->share('page_title', 'Add New Payment');
        return view('backend.payments.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'shop' => 'required',
            'collect_by' => 'required',
            'payment_type' => 'required',
            'amount' => 'required',
            'promise_cheque_date' => 'required',
//            'cheque_type' => 'required',
//            'cheque_no' => 'required',
//            'remarks' => 'required',
        ];
        $messages = [
            'promise_cheque_date.required' => 'This field is required!',
        ];
        $this->validate($request, $rules,$messages);
        $payment=$this->_paymentModel->InsertOrUpdatePayment($request);
        return redirect(url('payments'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $data['payment'] = Payment::findOrFail($id);
        $data['breadcrumbs'] = [
            [
                'title' => 'Payments',
                'url' => 'payments',
            ]
        ];
        view()->share('page_title', 'View Payment Detail');
        return view('backend.payments.show', $data);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['payment'] = Payment::findOrFail($id);
        $data['users'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
        })->get();
        $data['shops']=Shop::where('agency_id',Auth::user()->agency_id)->get();
        $data['banks']=Bank::all();
        $data['breadcrumbs'] = [
            [
                'title' => 'Payments',
                'url' => 'payments',
            ]
        ];
        view()->share('page_title', 'Modify Payment');
        return view('backend.payments.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'shop' => 'required',
            'collect_by' => 'required',
            'payment_type' => 'required',
            'amount' => 'required',
            'promise_cheque_date' => 'required',
//            'cheque_type' => 'required',
//            'cheque_no' => 'required',
//            'remarks' => 'required',
        ];
        $messages = [
            'promise_cheque_date.required' => 'This field is required!',
        ];
        $this->validate($request, $rules,$messages);
        $payment=$this->_paymentModel->InsertOrUpdatePayment($request,$id);
        return redirect()->back()->with("success", "Your record has been update successfully.");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $payment = Payment::findOrFail($id);
        $payment->delete();
        // Remove all Payment Images
        $img=PaymentImage::where('payment_id',$id)->select(['image'])->get();
        PaymentImage::where('payment_id',$id)->delete();
        if(count($img)>0){
            foreach ($img as $val){
                $file =public_path() .str_replace(url(''),"",$val['image']);
                if (file_exists($file)) {
                    @unlink($file);
                }
            }
        }
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }
    public function Test(){
//       PushNotification::setService('fcm')
//            ->setMessage([
//                'notification' => [
//                    'title'=>'This is the title',
//                    'body'=>'This is the message',
//                    'sound' => 'default'
//                ],
//                'data' => [
//                    'extraPayLoad1' => 'value1',
//                    'extraPayLoad2' => 'value2'
//                ]
//            ])
//            ->setApiKey('Server-API-Key')
//            ->setDevicesToken(['deviceToken1','deviceToken2','deviceToken3'])
//                        ->send()
//            ->getFeedback();
    }
}
