<?php

namespace App\Http\Controllers\backend;

use App\Area;
use App\Category;
use App\Country;
use App\Currency;
use App\Order;
use App\Product;
use App\ProductCategory;
use App\ProductDiscount;
use App\ProductImage;
use App\ProductPrice;
use App\Shop;
use App\ShopProductDiscount;
use App\TargetGrade;
use App\User;
use App\UserRole;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Auth;
use Session;
class ProductController extends BackendController
{
    /***
     * @var Product
     */
    private $_productModel;

    /***
     * Constructor
     *
     * @param $request
     * @param Product $productModel
     */
    public function __construct(Request $request, Product $productModel)
    {
        parent::__construct(  );
        $this->_productModel = $productModel;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $data['products']=$this->_productModel->listProducts($request);
        $data['categories'] = Category::all();
        $data['breadcrumbs'] = [
            [
                'title' => 'Products',
                'url' => 'products',
            ]
        ];
        view()->share('page_title', 'All Products');
        return view('backend.products.index',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['categories'] = Category::all();
        $data['currencies'] = Currency::all();
        $data['breadcrumbs'] = [
            [
                'title' => 'Products',
                'url' => 'products',
            ]
        ];
        view()->share('page_title', 'Add New Product');
        return view('backend.products.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'name' => 'required',
            'product_code' => 'required|max:30',
        ];
        $messsages=[];
//        if(count($request->input('prices'))>0){
//            foreach ($request->input('prices') as $key=>$price){
//                if(empty($price['price']) && $price['price'] !== '0'){
//                    $rules [$key.'price']='required';
//                    $messsages[$key.'price.required']='You cant leave Price field empty';
//                }
//            }
//        }
        $this->validate($request, $rules,$messsages);
        $product=$this->_productModel->InsertOrUpdateProduct($request);
        return redirect(url('products'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
     public function storesubproduct(Request $request){
    //dd($request);
     

     foreach ($request['name'] as $key => $value) {
        $item= new ProductCategory (); 
        $item->name = $value;
        $item->product_code = $request['product_code'][$key];
       if ($request->hasFile('subproduct')){
                        $filename = 'image-' . time() . rand(99, 199) . '.' . $request->file('subproduct')[$key]->getClientOriginalExtension();
                        $request->file('subproduct')[$key]->move(config('constants.UPLOAD_PATH') . 'products/', $filename);
                        if (isset($filename)){
                          
                                $item->product_id = $request->parent_id;
                                $file = public_path() .str_replace(url(''),"",$item->image_url);
                                if (file_exists($file)) {
                                    @unlink($file);
                                }
                                $item->image_url=url('/uploads/products/'.$filename);
                              //  dd($item);
                               $item->save();
                            
                        }
                    }
     


     }


      Session::flash('success', 'Sub product has been added');
       return back();            
                    
                    
}
public function updatesubproduct (Request $request){

   $item= ProductCategory::where('id',$request->subpro_id)->first();

        $item->name = $request->name;
        $item->product_code = $request->product_code;
       if ($request->hasFile('subproduct')){
                        $filename = 'image-' . time() . rand(99, 199) . '.' . $request->file('subproduct')->getClientOriginalExtension();
                        $request->file('subproduct')->move(config('constants.UPLOAD_PATH') . 'products/', $filename);
                        if (isset($filename)){
                          
                                $file = public_path() .str_replace(url(''),"",$item->image_url);
                                if (file_exists($file)) {
                                    @unlink($file);
                                }
                                $item->image_url=url('/uploads/products/'.$filename);
                              //  dd($item);
                               $item->save();
                            
                        }
                    }
                    

                     Session::flash('success', 'Sub product has been Updated');
       return back(); 

}

    public function addsubproduct($id){
       $data['product'] = Product::findOrFail($id);
        $data['breadcrumbs'] = [
            [
                'title' => 'Products',
                'url' => 'products',
            ]
        ];
         view()->share('page_title', 'Add Sub Products');
        return view('backend.products.addsubproduct', $data);
    }

     public function editsubproduct($id){
       $data['product'] = ProductCategory::findOrFail($id);
       
        $data['breadcrumbs'] = [
            [
                'title' => 'Edit_SubProducts',
                'url' => 'editsubproducts',
            ]
        ];
         view()->share('page_title', 'Edit Sub Products');
        return view('backend.products.editsubproduct', $data);
    }
     
    public function show($id)
    {
        $data['product'] = Product::findOrFail($id);
        $data['subproduct'] = ProductCategory::where('product_id',$id)->get();
        $data['breadcrumbs'] = [
            [
                'title' => 'Products',
                'url' => 'products',
            ]
        ];
        view()->share('page_title', 'View Product Detail');
        return view('backend.products.show', $data);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['categories'] = Category::all();
        $data['product'] = Product::findOrFail($id);
        $data['currencies'] = Currency::all();
        $data['breadcrumbs'] = [
            [
                'title' => 'Products',
                'url' => 'products',
            ]
        ];
        view()->share('page_title', 'Modify Product');
        return view('backend.products.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'name' => 'required',
            'product_code' => 'required|max:30',
        ];
        $messsages=[];
//        if(count($request->input('prices'))>0){
//            foreach ($request->input('prices') as $key=>$price){
//                if(empty($price['price'])&& $price['price'] !== '0'){
//                    $rules [$key.'price']='required';
//                    $messsages[$key.'price.required']='You cant leave Price field empty';
//                }
//            }
//        }
        $this->validate($request, $rules,$messsages);
        $product=$this->_productModel->InsertOrUpdateProduct($request,$id);
        return redirect()->back()->with("success", "Your record has been Updated successfully.");
        
       //return dd($request->all());
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $product = Product::findOrFail($id);
        $product->delete();

        // Remove all Product Images
        $img=ProductImage::where('product_id',$id)->select(['image_url'])->get();
        ProductImage::where('product_id',$id)->delete();
        if(count($img)>0){
            foreach ($img as $val){
                $file =public_path() .str_replace(url(''),"",$val['image_url']);
                if (file_exists($file)) {
                    @unlink($file);
                }
            }
        }
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }
    /**
     * Ajax Call Items List
     */
    public function  All_Product(){
        try {
            $statusCode = 200;
            $response = [];
            $response = Product::select(['id','name','is_scheme','scheme_quantity','scheme_free_quantity'])->get();
        } catch (Exception $ex) {
            $statusCode = 400;
        } finally {
            return \Illuminate\Support\Facades\Response::json($response, $statusCode);
        }
    }
    /**
     * Ajax Call ProductwithCategory List
     */
    public function  AllProductwithTarget(){
        try {
            $statusCode = 200;
            $response = [];
            $response['products'] = Product::select(['id','name'])->get();
            $response['target_grade'] = TargetGrade::select(['id','grade','value'])->get();
        } catch (Exception $ex) {
            $statusCode = 400;
        } finally {
            return \Illuminate\Support\Facades\Response::json($response, $statusCode);
        }
    }
    /**
     * Ajax Call AllProductwithDiscountGrade List
     */
    public function  AllProductwithDiscountGrade($id,Request $request){
        try {
            $statusCode = 200;
            $response = [];
            if(!empty($id)){
                $products=Product::select(['id','name'])->get();
                $discounts=ProductDiscount::all();
                $productWithDiscount=[];
                foreach($products as $key=>$product){
                    $productWithDiscount[$key]=$product;
                    $Discount=[];
                    foreach($discounts as $index=>$discount){
                        $Discount[$index]['id']=$discount->id;
                        $price=ProductPrice::where('currency_id',(int)$id)->where('product_id',(int)$product->id)->first();
                        $price=$price['price'];
                        if($discount->grade=='D'){
                            $Discount[$index]['grade']= $discount->grade;
                            $Discount[$index]['discount-price']= round($price, 2);
                        }else{
                            $Discount[$index]['grade']= $discount->grade;
                            $Discount[$index]['discount-price']=round(($price)*(($discount->value)/100),2);
                        }
                    }
                    $productWithDiscount[$key]['discount']=$Discount;
                }
                $response=$productWithDiscount;
            }else{
                $response = [];
            }
        } catch (Exception $ex) {
            $statusCode = 400;
        } finally {
            return \Illuminate\Support\Facades\Response::json($response, $statusCode);
        }
    }
    /**
     * Ajax Call ProductwithCustomerPrice List
     */
    public function  ProductwithCustomerPrice(Request $request){
        try {
            $statusCode = 200;
            $response = [];
            $product_id=$request->get('product_id');
            $shop_id=$request->get('shop_id');

            if(!empty($product_id)){
                $discount=0;
                $shop=Shop::select(['id','currency_id','customer_type'])->where('id',$shop_id)->with(['currency'])->first();
                $customer_type=$shop->customer_type;
                $product=Product::select(['id','name','is_scheme','scheme_quantity','scheme_free_quantity'])->where('id',$product_id)->first();
                if($shop['currency_id']!=1){
                    $grade_id =ShopProductDiscount::select(['id','product_discount_id'])->where('product_id',$product_id)->where('shop_id',$shop_id)->with(['discounts'])->first();
                     if(!empty($grade_id) && $grade_id->discounts->grade!='D'){
                        $discount=$grade_id->discounts->value;
                    }
                }
                $actual_price=0;
                if(!empty($product) && count($product->ProductPrices)>0){
                    foreach ($product->ProductPrices as $value){
                        if($value['currency_id']==$shop['currency_id']){
                            if($shop['currency_id']==1){
                                $actual_price=round($value['retail_price']*12);
                                break;
                            }else{

                                if($customer_type=='Wholesaler')
                                    $actual_price=round($value['retail_price']*12)+($discount);
                                if($customer_type=='Retail Saler')
                                    $actual_price=round($value['wholesale_price']*12)+($discount);
                                if($customer_type=='Distributer')
                                    $actual_price=round($value['distributor_price']*12)+($discount);
                                break;
                            }
                        }
                    }
                }
                $response['actual_price']=$actual_price;
                $response['is_scheme']=$product->is_scheme;
                $response['scheme_quantity']=$product->scheme_quantity;
                $response['scheme_free_quantity']=$product->scheme_free_quantity;
                if($product->is_scheme){
                    $response['scheme']=$product->scheme_quantity.'+'.$product->scheme_free_quantity;
                }else{
                    $response['scheme']='No Scheme';
                }

            }else{
                $response = [];
            }
        } catch (Exception $ex) {
            $statusCode = 400;
        } finally {
            return \Illuminate\Support\Facades\Response::json($response, $statusCode);
        }
    }
// Search
    public function Search(Request $request)
    {
        try {
            $statusCode = 200;
            $response = [];
            switch ($request->input('type')) {
                case 'Customer':
                    $shop = Shop::select(['id','name','email','location','phone_1','customer_type','shop_type','Category'])
                        ->where('name', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('email', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('location', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('phone_1', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('customer_type', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('shop_type', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('Category', 'like', '%' . $request->input('search_term') . '%')
                        ->get();
                    if (!empty($shop))
                        $response = $shop;
                    break;
                case 'Order':
                    $order = Order::select(['id', 'name','type','product_code','retail_price','wholesale_price','distributor_price','stock_available'])
                        ->where('name', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('type', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('product_code', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('retail_price', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('wholesale_price', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('distributor_price', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('stock_available', 'like', '%' . $request->input('search_term') . '%')
                        ->get();
                    if (!empty($order))
                        $response = $order;
                    break;
                case 'Product':
                    $product = Product::select(['id', 'name','type','product_code','retail_price','wholesale_price','distributor_price','stock_available'])
                        ->where('name', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('type', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('product_code', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('retail_price', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('wholesale_price', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('distributor_price', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('stock_available', 'like', '%' . $request->input('search_term') . '%')
                        ->get();
                    if (!empty($product))
                        $response = $product;
                    break;
                case 'Area':
                    $area = Area::select(['id', 'name'])
                        ->where('name', 'like', '%' . $request->input('search_term') . '%')
                        ->get();
                    if (!empty($area))
                        $response = $area;
                    break;
                case 'Shop':
                    $shop = Shop::select(['id', 'name'])
                        ->where('name', 'like', '%' . $request->input('search_term') . '%')
                        ->get();
                    if (!empty($shop))
                        $response = $shop;
                    break;
                case 'User':
                    $data = User::select(['id', 'email','firstname','lastname','username','phone_1','cnic','father_name'])
                        ->where('email', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('firstname', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('lastname', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('username', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('phone_1', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('cnic', 'like', '%' . $request->input('search_term') . '%')
                        ->orwhere('father_name', 'like', '%' . $request->input('search_term') . '%')
                        ->get();
                    if (!empty($data))
                        $response = $data;
                    break;
                default:
                    break;

            }
        } catch (Exception $ex) {
            $statusCode = 400;
        } finally {
            return \Illuminate\Support\Facades\Response::json($response, $statusCode);
        }
    }
    // get Product Categories
    public function productCategories($id){
       $data= ProductCategory::where('product_id',$id)->with(['product_prices'=>function($query){$query->where('currency_id',1)->get();}])->get();
       return $data;
    }
}
