<?php

namespace App\Http\Controllers\backend;

use App\ProductDiscount;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class ProductDiscountController extends BackendController
{
    /***
     * @var ProductDiscount
     */
    private $_Model;

    /***
     * Constructor
     *
     * @param $request
     * @param ProductDiscount $targetModel
     */
    public function __construct(Request $request, ProductDiscount $Model)
    {
        parent::__construct(  );
        $this->_Model = $Model;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $data['product_discounts']=$this->_Model->listProductDiscount($request);
        $data['breadcrumbs'] = [
            [
                'title' => 'Product Discount',
                'url' => 'product_discount',
            ]
        ];
        view()->share('page_title', 'All Product Discount');
        return view('backend.product_discounts.index',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['breadcrumbs'] = [
            [
                'title' => 'Product Discount',
                'url' => 'product_discount',
            ]
        ];
        view()->share('page_title', 'Add New Product Discount');
        return view('backend.product_discounts.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'grade' => 'required',
            'discount' => 'required',
        ];
        $this->validate($request, $rules);
        $result=$this->_Model->InsertOrUpdateDiscounts($request);
        return redirect(url('product_discount'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['product_discount'] = ProductDiscount::findOrFail($id);
        $data['breadcrumbs'] = [
            [
                'title' => 'Product Discount',
                'url' => 'product_discount',
            ]
        ];
        view()->share('page_title', 'Modify Product Discount');
        return view('backend.product_discounts.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'grade' => 'required',
            'discount' => 'required',
        ];
        $this->validate($request, $rules);
        $results=$this->_Model->InsertOrUpdateDiscounts($request,$id);
        return redirect()->back()->with("success", "Your record has been update successfully.");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $result = ProductDiscount::findOrFail($id);
        $result->delete();
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }
}
