<?php

namespace App\Http\Controllers\backend;

use App\Area;
use App\Country;
use App\Currency;
use App\Job;
use App\Order;
use App\Payment;
use App\Product;
use App\ProductDiscount;
use App\ProductPrice;
use App\Region;
use App\Role;
use App\Shop;
use App\ShopImage;
use App\TargetVisit;
use App\User;
use App\UserArea;
use App\UserRole;
use Barryvdh\DomPDF\Facade as PDF;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Auth;
use Illuminate\Support\Facades\App;

class ShopController extends BackendController
{
    /***
     * @var Shop
     */
    private $_shoptModel;

    /***
     * Constructor
     *
     * @param $request
     * @param Shop $shopModel
     */
    public function __construct(Request $request, Shop $shopModel)
    {
        parent::__construct(  );
        $this->_shoptModel = $shopModel;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $data['shops']=$this->_shoptModel->listShops($request);
        $data['countries']=Country::all();
        $data['sales_officers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
        })->get();
        $data['breadcrumbs'] = [
            [
                'title' => 'Customer',
                'url' => 'customers',
            ]
        ];
        view()->share('page_title', 'All Customers');
        return view('backend.shops.index',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['sales_officers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so')
                  ->orwhere('name', '=', 'ase');
        })->get();
        $data['target_visits']=TargetVisit::all();
        $data['countries']=Country::all();
        $data['currencies']=Currency::all();
        $products=Product::select(['id','name'])->get();
        $discounts=ProductDiscount::all();
        $productWithDiscount=[];
        foreach($products as $key=>$product){
            $productWithDiscount[$key]=$product;
            $Discount=[];
            foreach($discounts as $index=>$discount){
                $obj1 = new \stdClass;
                $obj1->id=$discount->id;
                $obj1->grade=$discount->grade;
                foreach ($data['currencies'] as $currency){
                    $price=ProductPrice::where('currency_id',(int)$currency->id)->where('product_id',(int)$product->id)->first();
                    $retail_price=$price['retail_price'];
                    $wholesale_price=$price['wholesale_price'];
                    $distributor_price=$price['distributor_price'];
                    if($discount->grade=='D'){
                        if($currency->id==1){
                            $obj1->PKR_retail_price=round(12*$retail_price);
                            $obj1->PKR_wholesale_price=round(12*$wholesale_price);
                            $obj1->PKR_distributor_price=round(12*$distributor_price);
                        }
                        if($currency->id==2){
                            $obj1->AED_retail_price=round(12*$retail_price);
                            $obj1->AED_wholesale_price=round(12*$wholesale_price);
                        }
                    }else{
                        if($currency->id==1){
                            $obj1->PKR_retail_price=round(((12*$retail_price))+($discount->value));
                            $obj1->PKR_wholesale_price=round(((12*$wholesale_price))+($discount->value));
                            $obj1->PKR_distributor_price=round(((12*$distributor_price))+($discount->value));
                        }
                        if($currency->id==2){
                            $obj1->AED_retail_price=round(((12*$retail_price))+($discount->value));
                            $obj1->AED_wholesale_price=round(((12*$wholesale_price))+($discount->value));
                        }
                    }
                }
                $Discount[]=$obj1;
            }
            $productWithDiscount[$key]['discount']=$Discount;
        }
        $data['products']=$productWithDiscount;


        $data['breadcrumbs'] = [
            [
                'title' => 'Customers',
                'url' => 'customers',
            ]
        ];
        view()->share('page_title', 'Add New Customer');
        return view('backend.shops.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'name' => 'required|max:30',
            'phone_1' => 'required',
            'sale_officer' => 'required',
            'area' => 'required',
            'target_visit' => 'required',
            'currency' => 'required',
            'proprietor.name' => 'required|max:30',
            'proprietor.phone_1' => 'required|max:30',
            'contact_person.name' => 'required|max:30',
            'contact_person.phone_1' => 'required|max:30',
        ];
        $this->validate($request, $rules);
        $shop=$this->_shoptModel->InsertOrUpdateShop($request);
        return redirect(url('customers'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $data['shop'] = Shop::where('id',$id)->with(['stock'=>function($query){$query->with(['product'=>function($query){$query->select(['id','name']);}]);}])->first();
        $data['breadcrumbs'] = [
            [
                'title' => 'Customers',
                'url' => 'customers',
            ]
        ];
        view()->share('page_title', 'View Customer Detail');
        return view('backend.shops.show', $data);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['sales_officers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so')
            ->orwhere('name', '=', 'ase');
        })->get();
        $data['shop'] = Shop::findOrFail($id);
        $data['images'] = $data['shop']->shopImages()->orderBy('id', 'desc')->paginate(20);
        $data['regions'] = Region::all();
        $data['countries']=Country::all();
        $data['target_visits']=TargetVisit::all();
        $data['currencies']=Currency::all();
        $products=Product::select(['id','name'])->get();
        $discounts=ProductDiscount::all();
        $productWithDiscount=[];
        foreach($products as $key=>$product){
            $productWithDiscount[$key]=$product;
            $Discount=[];
            foreach($discounts as $index=>$discount){
                $obj1 = new \stdClass;
                $obj1->id=$discount->id;
                $obj1->grade=$discount->grade;
                foreach ($data['currencies'] as $currency){
                    $price=ProductPrice::where('currency_id',(int)$currency->id)->where('product_id',(int)$product->id)->first();
                    $retail_price=$price['retail_price'];
                    $wholesale_price=$price['wholesale_price'];
                    $distributor_price=$price['distributor_price'];
                    if($discount->grade=='D'){
                        if($currency->id==1){
                            $obj1->PKR_retail_price=round(12*$retail_price);
                            $obj1->PKR_wholesale_price=round(12*$wholesale_price);
                            $obj1->PKR_distributor_price=round(12*$distributor_price);
                        }
                        if($currency->id==2){
                            $obj1->AED_retail_price=round(12*$retail_price);
                            $obj1->AED_wholesale_price=round(12*$wholesale_price);
                        }
                    }else{
                        if($currency->id==1){
                            $obj1->PKR_retail_price=round(((12*$retail_price))+($discount->value));
                            $obj1->PKR_wholesale_price=round(((12*$wholesale_price))+($discount->value));
                            $obj1->PKR_distributor_price=round(((12*$distributor_price))+($discount->value));
                        }
                        if($currency->id==2){
                            $obj1->AED_retail_price=round(((12*$retail_price))+($discount->value));
                            $obj1->AED_wholesale_price=round(((12*$wholesale_price))+($discount->value));
                        }
                    }
                }
                $Discount[]=$obj1;
            }
            $productWithDiscount[$key]['discount']=$Discount;
        }
        $data['products']=$productWithDiscount;
        $data['breadcrumbs'] = [
            [
                'title' => 'Customers',
                'url' => 'customers',
            ]
        ];
        view()->share('page_title', 'Modify Customer');
        return view('backend.shops.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'name' => 'required|max:30',
            'phone_1' => 'required',
            'sale_officer' => 'required',
            'area' => 'required',
            'target_visit' => 'required',
            'currency' => 'required',
            'proprietor.name' => 'required|max:30',
            'proprietor.phone_1' => 'required|max:30',
            'contact_person.name' => 'required|max:30',
            'contact_person.phone_1' => 'required|max:30',

        ];
        $this->validate($request, $rules);
        $shop=$this->_shoptModel->InsertOrUpdateShop($request,$id);
        return redirect()->back()->with("success", "Your record has been Updated successfully.");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $shop = Shop::findOrFail($id);
        $shop->delete();

        // Remove all Shop Images
        $img=ShopImage::where('shop_id',$id)->select(['image_url'])->get();
        ShopImage::where('shop_id',$id)->delete();
        if(count($img)>0){
            foreach ($img as $val){
                $file =public_path() .str_replace(url(''),"",$val['image_url']);
                if (file_exists($file)) {
                    @unlink($file);
                }
            }
        }
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }

    public function uploadImage(Request $request){
        $response = ['error' => false, 'message' => 'Successfully uploaded.'];
        return response()->json($response);
    }
    /**
    Get Sales Officer areas.
     */
    public function sales_officerAreas($id,Request $request)
    {
        $users=UserArea::select(['area_id'])->where('user_id',$id)->get();
        $user_area=[];
        foreach ($users as $user){
            if(isset($user['area_id']) && !empty($user['area_id'])){
                $user_area[]=$user['area_id'];
            }
        }
        $areas=Area::select(['id','name'])->whereIn('id', $user_area)->get();
        if($request->get('type')=='edit')
            return $areas;
        $all_area=[];
        if(count($areas)>0){
            foreach ($areas as $key=>$area){
                // unset areas if already exit on job on specific date,,
                  $job=Job::where('area_id',$area['id'])->where('user_id',$id)->whereDate('end_date', '>', $request->get('start_date'))->get();
                if(count($job)>0){
                    unset($areas[$key]);
                }
                if(isset($areas[$key]))
                    $all_area[]=$areas[$key];
            }
        }
        return $all_area;
    }
    /**
    Get salesOfficerCustomers
     */
    public function salesOfficerCustomers($id)
    {
       $data=[];
       $user=User::select(['id','country_id'])->where('id',$id)->first();
       $data['country']=$user->country_id;
       $data['shops']= Shop::select(['id','name'])->where('sale_officer_id',$id)->get();
       return $data;
    }
    // Customer Ledger
    public function customerLedger($id,Request $request){
        $download=false;
        $all=false;
        $shop=Shop::select(['id','opening_balance','balance','name'])->where('id',$id)->first();
        $data['opening_balance']=$shop['opening_balance'];
        $data['balance']=$shop['balance'];
        $data['customer']=$shop['name'];
        if($request->input('all')=='true'){
            $all=true;
        }else{
            $all=false;
        }
        if($request->input('start_date') && !empty($request->input('start_date')) && $request->input('end_date') && !empty($request->input('end_date'))){
            $orders = Order::where('shop_id',$id)->where('status','Delivered')
                ->whereBetween('date_to_deliver',[$request->input('start_date'),$request->input('end_date')])
                ->whereNotIn('type', ['Sample'])->orderBy('date_to_deliver', 'Desc')->get()->toarray();
            $payments = Payment::where('shop_id',$id)->where('payment_type','Cash')
                ->whereBetween('promise_cheque_date',[$request->input('start_date'),$request->input('end_date')])
                ->orderBy('promise_cheque_date', 'Desc')->get()->toarray();
        }else{
            $orders = Order::where('shop_id',$id)->where('status','Delivered')->whereNotIn('type', ['Sample'])->orderBy('date_to_deliver', 'Desc')->get()->toarray();
            $payments = Payment::where('shop_id',$id)->where('payment_type','Cash')->orderBy('promise_cheque_date', 'Desc')->get()->toarray();
        }


        $ledger=[];
        $size=0;

        if(count($orders)>0){
            foreach ($orders as $key=>$order){
                $ledger[$key]=$order;
                $ledger[$key]['date']=$order['date_to_deliver'];
                $ledger[$key]['ledger_type']='order';

            }
            $size=count($orders);
        }
        if(count($payments)>0){
            foreach ($payments as $index=>$payment){
                $ledger[$size]=$payment;
                $ledger[$size]['date']=$payment['promise_cheque_date'];
                $ledger[$size]['ledger_type']='payment';
                $size++;
            }
        }
        usort($ledger, function($a, $b) {
            return strtotime($a['date']) - strtotime($b['date']);
        });
//        $ledger=array_reverse($ledger);
        $data['ledgers'] = $ledger;

        if($request->input('download')=='true' ){
            $all=true;
            $data['all'] = $all;
            $pdf = PDF::loadView('pdf.ledger',$data);
            return $pdf->download('invoice.pdf');

        }
        $data['all'] = $all;
        $data['breadcrumbs'] = [
            [
                'title' => 'Customers',
                'url' => 'customers',
            ]
        ];
        view()->share('page_title', 'Customer Ledger');
        return view('backend.shops.ledger',$data);

    }
}
