<?php

namespace App\Http\Controllers\backend;

use App\Product;
use App\SoTarget;
use App\SoTargetDetail;
use App\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Auth;
class SoTargetController extends BackendController
{
    /***
     * @var SoTarget
     */
    private $_Model;

    /***
     * Constructor
     *
     * @param $request
     * @param SoTarget $targetModel
     */
    public function __construct(Request $request, SoTarget $Model)
    {
        parent::__construct(  );
        $this->_Model = $Model;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $data['sales_officers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
            $query->orwhere('name', '=', 'ase');
        })->get();
        $data['so_targets']=$this->_Model->listTargets($request);
        $data['breadcrumbs'] = [
            [
                'title' => 'SO Targets',
                'url' => 'so_targets',
            ]
        ];
        view()->share('page_title', 'All SO Target');
        return view('backend.so_target.index',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['sales_officers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
            $query->orwhere('name', '=', 'ase');
        })->get();
        $data['products']=Product::select('id','name')->get()->toarray();;
        $data['breadcrumbs'] = [
            [
                'title' => 'SO Target',
                'url' => 'so_targets',
            ]
        ];
        view()->share('page_title', 'Add New Target');
        return view('backend.so_target.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'sale_officer' => 'required',
            'date' => 'required',
        ];
        $this->validate($request, $rules);

        $so=$this->_Model->InsertOrUpdate($request);
        return redirect(url('so_targets'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $data['so_target'] = SoTarget::where('id',$id)->first();
        $data['breadcrumbs'] = [
            [
                'title' => 'SO Targets',
                'url' => 'so_targets',
            ]
        ];
        view()->share('page_title', 'View SO Target Detail');
        return view('backend.so_target.show', $data);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['sales_officers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
            $query->orwhere('name', '=', 'ase');
        })->get();
        $data['products']=Product::select('id','name')->get()->toarray();
        $data['so_target'] = SoTarget::findOrFail($id);
        $data['breadcrumbs'] = [
            [
                'title' => 'SO Target',
                'url' => 'so_targets',
            ]
        ];
        view()->share('page_title', 'Modify SO Target');
        return view('backend.so_target.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'sale_officer' => 'required',
            'date' => 'required',
        ];
        $this->validate($request, $rules);
        $so=$this->_Model->InsertOrUpdate($request,$id);
        return redirect()->back()->with("success", "Your record has been update successfully.");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $target = SoTarget::findOrFail($id);
        $target->delete();
        SoTargetDetail::where('so_target_id',$id)->delete();
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }
}
