<?php

namespace App\Http\Controllers\backend;

use App\Target;
use App\TargetDetail;
use App\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Auth;
class TargetController extends BackendController
{
    /***
     * @var Target
     */
    private $_targetModel;

    /***
     * Constructor
     *
     * @param $request
     * @param Target $targetModel
     */
    public function __construct(Request $request, Target $targetModel)
    {
        parent::__construct(  );
        $this->_targetModel = $targetModel;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $data['sales_officers'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'rsm');
        })->get();
        $data['targets']=$this->_targetModel->listTargets($request);
        $data['breadcrumbs'] = [
            [
                'title' => 'Sales & Recovery Targets',
                'url' => 'targets',
            ]
        ];
        view()->share('page_title', 'All Sales & Recovery Target');
        return view('backend.targets.index',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['all_rsm'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'rsm');
        })->get();
        $data['breadcrumbs'] = [
            [
                'title' => 'Sales & Recovery Target',
                'url' => 'targets',
            ]
        ];
        view()->share('page_title', 'Add New Target');
        return view('backend.targets.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'rsm' => 'required',
            'date_start' => 'required',
            'date_end' => 'required',
            'sales_target' => 'required',
            'recovery_target' => 'required',
        ];
        $this->validate($request, $rules);

        $so=$this->_targetModel->InsertOrUpdate($request);
        return redirect(url('targets'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $data['target'] = Target::where('id',$id)->first();
        $data['breadcrumbs'] = [
            [
                'title' => 'Targets',
                'url' => 'targets',
            ]
        ];
        view()->share('page_title', 'View Target Detail');
        return view('backend.targets.show', $data);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['all_rsm'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'rsm');
        })->get();
        $data['target'] = Target::findOrFail($id);
        $data['breadcrumbs'] = [
            [
                'title' => 'Sales & Recovery Target',
                'url' => 'targets',
            ]
        ];
        view()->share('page_title', 'Modify Sales & Recovery Target');
        return view('backend.targets.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'rsm' => 'required',
            'date_start' => 'required',
            'date_end' => 'required',
            'sales_target' => 'required',
            'recovery_target' => 'required',
        ];
        $this->validate($request, $rules);

        $so=$this->_targetModel->InsertOrUpdate($request,$id);
        return redirect()->back()->with("success", "Your record has been update successfully.");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $target = Target::findOrFail($id);
        $target->delete();
        TargetDetail::where('target_id',$id)->delete();
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }
}
