<?php

namespace App\Http\Controllers\backend;

use App\TargetGrade;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Auth;
class TargetGradeController extends BackendController
{
    /***
     * @var targetgrade
     */
    private $_targetgradeModel;

    /***
     * Constructor
     *
     * @param $request
     * @param TargetGrade $targetgradeModel
     */
    public function __construct(Request $request, TargetGrade $targetgradeModel)
    {
        parent::__construct(  );
        $this->_targetgradeModel = $targetgradeModel;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $data['target_grades']=$this->_targetgradeModel->listTargetGrades($request);
        $data['breadcrumbs'] = [
            [
                'title' => 'Target Grades',
                'url' => 'target_grades',
            ]
        ];
        view()->share('page_title', 'All Target Grades');
        return view('backend.target_grades.index',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['breadcrumbs'] = [
            [
                'title' => 'Target Grades',
                'url' => 'target_grades',
            ]
        ];
        view()->share('page_title', 'Add New Target Grade');
        return view('backend.target_grades.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'grade' => 'required',
            'value' => 'required',
        ];
        $this->validate($request, $rules);
        $target_grade=$this->_targetgradeModel->InsertOrUpdateTargetGrade($request);
        return redirect(url('target_grades'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['target_grade'] = TargetGrade::findOrFail($id);
        $data['breadcrumbs'] = [
            [
                'title' => 'Target Grades',
                'url' => 'target_grades',
            ]
        ];
        view()->share('page_title', 'Modify Target Grades');
        return view('backend.target_grades.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'grade' => 'required',
            'value' => 'required',
        ];
        $this->validate($request, $rules);
        $target_grade=$this->_targetgradeModel->InsertOrUpdateTargetGrade($request,$id);
        return redirect()->back()->with("success", "Your record has been update successfully.");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $target_grade = TargetGrade::findOrFail($id);
        $target_grade->delete();
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }
}
