<?php

namespace App\Http\Controllers\backend;

use App\TargetPoint;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class TargetPointController extends BackendController
{
    /***
     * @var TargetPoint
     */
    private $_targetModel;

    /***
     * Constructor
     *
     * @param $request
     * @param TargetPoint $targetModel
     */
    public function __construct(Request $request, TargetPoint $targetModel)
    {
        parent::__construct(  );
        $this->_targetModel = $targetModel;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $data['target_points']=$this->_targetModel->listTargetPoints($request);
        $data['breadcrumbs'] = [
            [
                'title' => 'Target Points',
                'url' => 'target_points',
            ]
        ];
        view()->share('page_title', 'All Target Points');
        return view('backend.target_points.index',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['breadcrumbs'] = [
            [
                'title' => 'Target Points',
                'url' => 'target_points',
            ]
        ];
        view()->share('page_title', 'Add New Target Point');
        return view('backend.target_points.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'type' => 'required',
            'points' => 'required',
        ];
        $this->validate($request, $rules);
        $target_points=$this->_targetModel->InsertOrUpdateTargetPoint($request);
        return redirect(url('target_points'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['target_point'] = TargetPoint::findOrFail($id);
        $data['breadcrumbs'] = [
            [
                'title' => 'Target Points',
                'url' => 'target_points',
            ]
        ];
        view()->share('page_title', 'Modify Target Point');
        return view('backend.target_points.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'type' => 'required',
            'points' => 'required',
        ];
        $this->validate($request, $rules);
        $target_points=$this->_targetModel->InsertOrUpdateTargetPoint($request,$id);
        return redirect()->back()->with("success", "Your record has been update successfully.");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $target_points = TargetPoint::findOrFail($id);
        $target_points->delete();
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }
}
