<?php

namespace App\Http\Controllers\backend;

use App\TargetVisit;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class TargetVisitController extends BackendController
{
    /***
     * @var TargetVisit
     */
    private $_targetModel;

    /***
     * Constructor
     *
     * @param $request
     * @param TargetVisit $targetModel
     */
    public function __construct(Request $request, TargetVisit $targetModel)
    {
        parent::__construct(  );
        $this->_targetModel = $targetModel;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $data['target_visits']=$this->_targetModel->listTargetVisits($request);
        $data['breadcrumbs'] = [
            [
                'title' => 'Target Visit',
                'url' => 'target_visit',
            ]
        ];
        view()->share('page_title', 'All Target Visit');
        return view('backend.target_visit.index',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['breadcrumbs'] = [
            [
                'title' => 'Target Visit',
                'url' => 'target_visit',
            ]
        ];
        view()->share('page_title', 'Add New Target Visit');
        return view('backend.target_visit.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'grade' => 'required',
            'value' => 'required',
        ];
        $this->validate($request, $rules);
        $target_visit=$this->_targetModel->InsertOrUpdateTargetVisit($request);
        return redirect(url('target_visit'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['target_visit'] = TargetVisit::findOrFail($id);
        $data['breadcrumbs'] = [
            [
                'title' => 'Target Visit',
                'url' => 'target_visit',
            ]
        ];
        view()->share('page_title', 'Modify Target Visit');
        return view('backend.target_visit.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'grade' => 'required',
            'value' => 'required',
        ];
        $this->validate($request, $rules);
        $target_visit=$this->_targetModel->InsertOrUpdateTargetVisit($request,$id);
        return redirect()->back()->with("success", "Your record has been update successfully.");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $target_visit = TargetVisit::findOrFail($id);
        $target_visit->delete();
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }
}
