<?php

namespace App\Http\Controllers\backend;

use App\Country;
use App\Order;
use App\Role;
use App\Shop;
use App\User;
use App\UserExpenseDetail;
use App\UserRole;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Mail;
class UserController extends BackendController
{
    /***
     * @var User
     */
    private $_userModel;

    /***
     * Constructor
     *
     * @param $request
     * @param User $userModel
     */
    public function __construct(Request $request, User $userModel)
    {
        parent::__construct(  );
        $this->_userModel = $userModel;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        
        $data['users']=$this->_userModel->listUsers($request);
        $data['roles']=Role::all();
        $data['countries'] = Country::all();
        $data['breadcrumbs'] = [
            [
                'title' => 'Users',
                'url' => 'users',
            ]
        ];
        view()->share('page_title', 'All Users');
        return view('backend.users.index',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['roles'] = Role::all();
        $data['countries'] = Country::all();
        $data['breadcrumbs'] = [
            [
                'title' => 'Users',
                'url' => 'users',
            ]
        ];
        view()->share('page_title', 'New Registration');
        return view('backend.users.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'firstname' => 'required',
            'username' => 'required|unique:users,username',
            'password' => 'required|min:3|max:30',
            'phone_1' => 'required|min:3|max:30',
        ];
        if(!empty($request->input('email'))){
            $rules['email'] = 'email|unique:users,email';
        }

        $this->validate($request, $rules);
        $user=$this->_userModel->InsertOrUpdateUser($request);
        return redirect(url('users'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $data['user']=User::findOrFail($id);
        $data['outstanding_balance']=Shop::where('sale_officer_id',$id)->sum('balance');
        $data['breadcrumbs'] = [
            [
                'title' => 'All User',
                'url' => 'users',
            ]
        ];
        view()->share('page_title', 'User Profile');
        return view('backend.users.show',$data);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['roles'] = Role::all();
        $data['countries'] = Country::all();
        $data['user'] = User::findOrFail($id);
        $data['breadcrumbs'] = [
            [
                'title' => 'Users',
                'url' => 'users',
            ]
        ];
        view()->share('page_title', 'Modify Registration');
        return view('backend.users.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'firstname' => 'required|min:3|max:30',
            'username' => 'required|min:3|max:30',
            'phone_1' => 'required',
        ];
        if($request->input('email')!=$request->input('old_email')){
            $rules['email'] = 'required|email|unique:users,email';
        }
        if($request->input('username')!=$request->input('old_username')){
            $rules['username'] = 'required|unique:users,username';
        }

        if($request->role_id=='4'){
            $rules['parent_type'] = 'required';

        }
        $this->validate($request, $rules);
        $user = $this->_userModel->InsertOrUpdateUser($request,$id);
        return redirect()->back()->with("success", "Your record has been updated successfully.");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $user = User::findOrFail($id);
        $file =public_path() .str_replace(url(''),"",$user->image);
        if (!empty($user->image)) {
            if (file_exists($file))
                unlink($file);
        }
        $user->delete();
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }

    /**
      Get User Parents.
     */
    public function userParent($id)
    {
        $role=UserRole::select(['user_id'])->where('role_id',$id)->get();
        $user=User::whereIn('id', $role)->get();
        return $user;
    }
    /**
      Get Supplier.
     */
    public function Supplier()
    {
        $data = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'su');
        })->get();
        return $data;
    }
    /**
      Test Mail.
     */
    public function Mail(Request $request)
    {
        $data=[];
        $data[]='a';
        $email='shakir130@hotmail.com';
        $subject='Test';
        Mail::send('email.test', $data, function($message){
            $message->from('adminpanel@biocospk.com', 'Biocos International Pvt Ltd');
            $message->to('shakir130@hotmail.com')->subject('Test');
        });
    }
    // RSM ASM SO & ASE ,
    public function rsmSo($id){
        $users=User::select('id','firstname','lastname')->where('rsm_id',$id)
            ->get();
        return json_encode($users);
    }
    //
    public function roles(){
        $data['roles']=Role::all();
        $data['breadcrumbs'] = [
            [
                'title' => 'Roles',
                'url' => 'roles',
            ]
        ];
        view()->share('page_title', 'Roles');
        return view('backend.roles',$data);
    }
    // Permission
    public function permissions(Request $request, $role_id)
    {
        $data['role'] = \App\Role::findOrFail($role_id);
        $ignore_ids = [];
        if (!empty($data['role']->perms)) {
            foreach ($data['role']->perms as $perm) {
                $ignore_ids[] = $perm->id;
            }
        }
        $data['breadcrumbs'] = [
            [
                'title' => 'Roles &amp; Permissions',
                'url' => 'roles',
            ],
        ];
        $data['permissions'] = \App\Permission::whereNotIn('id', $ignore_ids)->get();
        view()->share('page_title', $data['role']->display_name . ' Permissions');
        return view('backend.permissions', $data);
    }
    // update Permission
    public function update_permissions(Request $request)
    {
        $rules = [
            'id' => 'required|exists:permissions,id',
            'role' => 'required|exists:roles,id',
            'type' => 'required|in:allowed_permissions,disallowed_permissions'
        ];
        $this->validate($request, $rules);

        $permission = \App\Permission::findOrFail($request->id);
        $role = \App\Role::findOrFail($request->role);
        if ($request->type == 'allowed_permissions' ) {
            $role->attachPermission($permission);
        } elseif ($request->type == 'disallowed_permissions') {
            $role->detachPermission($permission);
        }

        return response()->json(['status' => 'ok']);
    }
    // Ledger
    public function Ledger($id,Request $request){
        $user=User::where('id',$id)->first();
        $data['full_name']=$user['firstname'].' '.$user['lastname'];
        $data['balance']=$user['balance'];
        $query = UserExpenseDetail::query();
        $query = $query->where('user_id',$id);
        if ($request->get('start_date') && !empty($request->get('start_date'))) {
            $query = $query->where('date','>=', $request->get('start_date'));
        }
        if ($request->get('end_date') && !empty($request->get('end_date'))) {
            $query = $query->where('date','<=', $request->get('end_date'));
        }
        $data['ledgers'] = $query->paginate(15);
        $data['breadcrumbs'] = [
            [
                'title' => 'Users',
                'url' => 'users',
            ]
        ];
        view()->share('page_title', 'User Ledger');
        return view('backend.users.ledger',$data);
    }
}
