<?php

namespace App\Http\Controllers\backend;

use App\Expense;
use App\User;
use App\UserExpense;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Auth;
class UserExpenseController extends BackendController
{
    /***
     * @var Expense
     */
    private $_Model;

    /***
     * Constructor
     *
     * @param $request
     * @param Expense $areaModel
     */
    public function __construct(Request $request, UserExpense $Model)
    {
        parent::__construct(  );
        $this->_Model = $Model;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $data['users'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
            $query->orwhere('name', '=', 'ase');
        })->get();
        $data['user_expenses']=$this->_Model->listExpense($request);
        $data['breadcrumbs'] = [
            [
                'title' => 'User Expense',
                'url' => 'user-expense',
            ]
        ];
        view()->share('page_title', 'All User Expense');
        return view('backend.user_expense.index',$data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['users'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
            $query->orwhere('name', '=', 'ase');
        })->get();
        $data['types']=Expense::all();
        $data['breadcrumbs'] = [
            [
                'title' => 'User Expense',
                'url' => 'user-expense',
            ]
        ];
        view()->share('page_title', 'Add New User Expense');
        return view('backend.user_expense.modify',$data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $rules = [
            'user' => 'required',
            'expense_type' => 'required',
            'date' => 'required',
            'amount' => 'required',
        ];
        $this->validate($request, $rules);
        $expense=$this->_Model->InsertOrUpdate($request);
        return redirect(url('user-expense'))->with('success', 'Your record has been added successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $data['expense'] = UserExpense::findOrFail($id);
        $data['breadcrumbs'] = [
            [
                'title' => 'User Expense',
                'url' => 'user-expense',
            ]
        ];
        view()->share('page_title', 'View Expense Detail');
        return view('backend.user_expense.show', $data);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['users'] = User::where('agency_id',Auth::user()->agency_id)->whereHas('roles', function($query) {
            $query->where('name', '=', 'so');
            $query->orwhere('name', '=', 'ase');
        })->get();
        $data['types']=Expense::all();
        $data['expense'] = UserExpense::findOrFail($id);
        $data['breadcrumbs'] = [
            [
                'title' => 'User Expense',
                'url' => 'user-expense',
            ]
        ];
        view()->share('page_title', 'Modify User Expense');
        return view('backend.user_expense.modify',$data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $rules = [
            'user' => 'required',
            'expense_type' => 'required',
            'date' => 'required',
            'amount' => 'required',
        ];
        $this->validate($request, $rules);
        $expense=$this->_Model->InsertOrUpdate($request,$id);
        return redirect()->back()->with("success", "Your record has been update successfully.");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $expense = UserExpense::findOrFail($id);
        $expense->delete();
        return redirect()->back()->with("success", "Your record has been Deleted successfully.");
    }
}
